@@ -66,19 +66,22 @@ func CheckArtifacts(ctx context.Context, cfg Config, out io.Writer) error {
 			fmt.Fprintln(out, " - Dependencies:", len(deps), "files")
 			fmt.Fprintf(out, " - Time to list dependencies: %v (2nd time: %v)\n", timeDeps1, timeDeps2)
 
-			timeSyncMap1, err := timeToConstructSyncMap(ctx, artifact, cfg)
-			if err != nil {
-				if _, isNotSupported := err.(build.ErrSyncMapNotSupported); !isNotSupported {
-					return fmt.Errorf("construct artifact dependencies: %w", err)
+			// Only check sync map if inferred sync is configured on artifact
+			if artifact.Sync != nil && len(artifact.Sync.Infer) > 0 {
+				timeSyncMap1, err := timeToConstructSyncMap(ctx, artifact, cfg)
+				if err != nil {
+					if _, isNotSupported := err.(build.ErrSyncMapNotSupported); !isNotSupported {
+						return fmt.Errorf("constructing inferred sync map: %w", err)
+					}
 				}
-			}
-			timeSyncMap2, err := timeToConstructSyncMap(ctx, artifact, cfg)
-			if err != nil {
-				if _, isNotSupported := err.(build.ErrSyncMapNotSupported); !isNotSupported {
-					return fmt.Errorf("construct artifact dependencies: %w", err)
+				timeSyncMap2, err := timeToConstructSyncMap(ctx, artifact, cfg)
+				if err != nil {
+					if _, isNotSupported := err.(build.ErrSyncMapNotSupported); !isNotSupported {
+						return fmt.Errorf("constructing inferred sync map: %w", err)
+					}
+				} else {
+					fmt.Fprintf(out, " - Time to construct sync map: %v (2nd time: %v)\n", timeSyncMap1, timeSyncMap2)
 				}
-			} else {
-				fmt.Fprintf(out, " - Time to construct sync-map: %v (2nd time: %v)\n", timeSyncMap1, timeSyncMap2)
 			}
 
 			timeMTimes1, err := timeToComputeMTimes(deps)
@@ -110,6 +113,8 @@ func typeOfArtifact(a *latestV1.Artifact) string {
 		return "Custom artifact"
 	case a.BuildpackArtifact != nil:
 		return "Buildpack artifact"
+	case a.KoArtifact != nil:
+		return "Ko artifact"
 	default:
 		panic("Unknown artifact")
 	}
