@@ -159,7 +159,11 @@ func (rc *RunContext) StatusCheckDeadlineSeconds() int {
 }
 
 func (rc *RunContext) SkipTests() bool {
-	return rc.Opts.SkipTests || len(rc.TestCases()) == 0
+	return rc.Opts.SkipTests
+}
+
+func (rc *RunContext) IsTestPhaseActive() bool {
+	return !rc.SkipTests() && len(rc.TestCases()) != 0
 }
 
 func (rc *RunContext) TransformableAllowList() []latestV1.ResourceFilter {
@@ -188,7 +192,8 @@ func (rc *RunContext) CacheFile() string                             { return rc
 func (rc *RunContext) ConfigurationFile() string                     { return rc.Opts.ConfigurationFile }
 func (rc *RunContext) CustomLabels() []string                        { return rc.Opts.CustomLabels }
 func (rc *RunContext) CustomTag() string                             { return rc.Opts.CustomTag }
-func (rc *RunContext) DefaultRepo() *string                          { return rc.Opts.DefaultRepo.Value() }
+func (rc *RunContext) DefaultRepo() *string                          { return rc.Cluster.DefaultRepo.Value() }
+func (rc *RunContext) MultiLevelRepo() *bool                         { return rc.Opts.MultiLevelRepo }
 func (rc *RunContext) Mode() config.RunMode                          { return rc.Opts.Mode() }
 func (rc *RunContext) DigestSource() string                          { return rc.Opts.DigestSource }
 func (rc *RunContext) DryRun() bool                                  { return rc.Opts.DryRun }
@@ -222,6 +227,9 @@ func (rc *RunContext) GetRunID() string                              { return rc
 func (rc *RunContext) RPCPort() *int                                 { return rc.Opts.RPCPort.Value() }
 func (rc *RunContext) RPCHTTPPort() *int                             { return rc.Opts.RPCHTTPPort.Value() }
 func (rc *RunContext) PushImages() config.BoolOrUndefined            { return rc.Opts.PushImages }
+func (rc *RunContext) JSONParseConfig() latestV1.JSONParseConfig {
+	return rc.DefaultPipeline().Deploy.Logs.JSONParse
+}
 
 func GetRunContext(ctx context.Context, opts config.SkaffoldOptions, configs []schemaUtil.VersionedConfig) (*RunContext, error) {
 	var pipelines []latestV1.Pipeline
@@ -263,7 +271,12 @@ func GetRunContext(ctx context.Context, opts config.SkaffoldOptions, configs []s
 	// TODO(https://github.com/GoogleContainerTools/skaffold/issues/3668):
 	// remove minikubeProfile from here and instead detect it by matching the
 	// kubecontext API Server to minikube profiles
-	cluster, err := config.GetCluster(ctx, opts.GlobalConfig, opts.MinikubeProfile, opts.DetectMinikube)
+	cluster, err := config.GetCluster(ctx, config.GetClusterOpts{
+		ConfigFile:      opts.GlobalConfig,
+		DefaultRepo:     opts.DefaultRepo,
+		MinikubeProfile: opts.MinikubeProfile,
+		DetectMinikube:  opts.DetectMinikube,
+	})
 	if err != nil {
 		return nil, fmt.Errorf("getting cluster: %w", err)
 	}
