@@ -21,10 +21,18 @@ import (
 	"errors"
 	"io/ioutil"
 	"os"
+	"path/filepath"
+
+	"github.com/spf13/afero"
 
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/output/log"
 )
 
+// Fs is the underlying filesystem to use for reading skaffold project files & configuration.  OS FS by default
+var Fs = afero.NewOsFs()
+
+var stdin []byte
+
 // ReadConfiguration reads a `skaffold.yaml` configuration and
 // returns its content.
 func ReadConfiguration(filename string) ([]byte, error) {
@@ -32,18 +40,33 @@ func ReadConfiguration(filename string) ([]byte, error) {
 	case filename == "":
 		return nil, errors.New("filename not specified")
 	case filename == "-":
-		return ioutil.ReadAll(os.Stdin)
+		if len(stdin) == 0 {
+			var err error
+			stdin, err = ioutil.ReadAll(os.Stdin)
+			if err != nil {
+				return []byte{}, err
+			}
+		}
+		return stdin, nil
 	case IsURL(filename):
 		return Download(filename)
 	default:
-		contents, err := ioutil.ReadFile(filename)
+		fp := filename
+		if !filepath.IsAbs(fp) {
+			dir, err := os.Getwd()
+			if err != nil {
+				return []byte{}, err
+			}
+			fp = filepath.Join(dir, fp)
+		}
+		contents, err := afero.ReadFile(Fs, fp)
 		if err != nil {
 			// If the config file is the default `skaffold.yaml`,
 			// then we also try to read `skaffold.yml`.
 			if filename == "skaffold.yaml" {
 				log.Entry(context.TODO()).Infof("Could not open skaffold.yaml: \"%s\"", err)
 				log.Entry(context.TODO()).Info("Trying to read from skaffold.yml instead")
-				contents, errIgnored := ioutil.ReadFile("skaffold.yml")
+				contents, errIgnored := afero.ReadFile(Fs, filepath.Join(filepath.Dir(fp), "skaffold.yml"))
 				if errIgnored != nil {
 					// Return original error because it's the one that matters
 					return nil, err
@@ -56,3 +79,14 @@ func ReadConfiguration(filename string) ([]byte, error) {
 		return contents, err
 	}
 }
+
+func ReadFile(filename string) ([]byte, error) {
+	if !filepath.IsAbs(filename) {
+		dir, err := os.Getwd()
+		if err != nil {
+			return []byte{}, err
+		}
+		filename = filepath.Join(dir, filename)
+	}
+	return afero.ReadFile(Fs, filename)
+}
